
* patch state and related changesets are detected from `mercurial phase`_ and
  `evolve`_ information

* patches are workflowable, so it's easy to find those which are in-progress or
  pending for review

* you can add comment and tasks to the patch or/and to each diff chunk

* notification about patches activity


.. _`mercurial phase`: http://mercurial.selenic.com/wiki/Phases
.. _`evolve`: http://mercurial.selenic.com/wiki/EvolveExtension
